@@ -14,6 +14,7 @@ from .logs import evaluate_version_bump  # noqa
 
 from .parser_angular import parse_commit_message as angular_parser  # noqa isort:skip
 from .parser_tag import parse_commit_message as tag_parser  # noqa isort:skip
+from .parser_emoji import parse_commit_message as emoji_parser  # noqa isort:skip
 
 logger = logging.getLogger(__name__)
 
@@ -48,17 +49,12 @@ def get_current_version_by_config_file() -> str:
 
     with open(filename, "r") as fd:
         file_text = fd.read()
-        # checks for variable in the format variable=version
+        # Check for variable in the format variable=version or variable:version
         parts = re.search(
-            r'^{0}\s*=\s*[\'"]([^\'"]*)[\'"]'.format(variable), file_text, re.MULTILINE
+            r'^{0}\s*[=:]\s*[\'"]([^\'"]*)[\'"]'.format(variable),
+            file_text,
+            re.MULTILINE,
         )
-        # checks for variable in the format variable:version
-        if not parts:
-            parts = re.search(
-                r'{0}\s*:\s*[\'"]([^\'"]*)[\'"]'.format(variable),
-                file_text,
-                re.MULTILINE,
-            )
         if not parts:
             raise ImproperConfigurationError
 
